@@ -2,17 +2,16 @@ package LWP::Protocol;
 
 use base 'LWP::MemberMixin';
 
-our $VERSION = "6.16";
+our $VERSION = '6.17';
 
 use strict;
 use Carp ();
 use HTTP::Status ();
 use HTTP::Response;
+use Try::Tiny qw(try catch);
 
 my %ImplementedBy = (); # scheme => classname
 
-
-
 sub new
 {
     my($class, $scheme, $ua) = @_;
@@ -62,16 +61,21 @@ sub implementor
     no strict 'refs';
     # check we actually have one for the scheme:
     unless (@{"${ic}::ISA"}) {
-	# try to autoload it
-	eval "require $ic";
-	if ($@) {
-	    if ($@ =~ /Can't locate/) { #' #emacs get confused by '
-		$ic = '';
-	    }
-	    else {
-		die "$@\n";
-	    }
-	}
+        # try to autoload it
+        try {
+            (my $class = $ic) =~ s{::}{/}g;
+            $class .= '.pm' unless $class =~ /\.pm$/;
+            require $class;
+        }
+        catch {
+            my $error = $_;
+            if ($error =~ /Can't locate/) {
+                $ic = '';
+            }
+            else {
+                die "$error\n";
+            }
+        };
     }
     $ImplementedBy{$scheme} = $ic if $ic;
     $ic;
@@ -96,8 +100,8 @@ sub collect
     my $content;
     my($ua, $max_size) = @{$self}{qw(ua max_size)};
 
-    eval {
-	local $\; # protect the print below from surprises
+    try {
+        local $\; # protect the print below from surprises
         if (!defined($arg) || !$response->is_success) {
             $response->{default_add_content} = 1;
         }
@@ -160,17 +164,15 @@ sub collect
                 last;
             }
         }
+    }
+    catch {
+        my $error = $_;
+        chomp($error);
+        $response->push_header('X-Died' => $error);
+        $response->push_header("Client-Aborted", "die");
     };
-    my $err = $@;
     delete $response->{handlers}{response_data};
     delete $response->{handlers} unless %{$response->{handlers}};
-    if ($err) {
-        chomp($err);
-        $response->push_header('X-Died' => $err);
-        $response->push_header("Client-Aborted", "die");
-        return $response;
-    }
-
     return $response;
 }
 
