@@ -3,8 +3,9 @@ package LWP::UserAgent;
 use strict;
 
 use base qw(LWP::MemberMixin);
-our $VERSION = "6.16";
+our $VERSION = '6.17';
 
+use Carp ();
 use HTTP::Request ();
 use HTTP::Response ();
 use HTTP::Date ();
@@ -12,7 +13,8 @@ use HTTP::Date ();
 use LWP ();
 use LWP::Protocol ();
 
-use Carp ();
+use Scalar::Util qw(blessed);
+use Try::Tiny qw(try catch);
 
 
 sub new
@@ -169,10 +171,13 @@ sub send_request
         }
 
         unless ($protocol) {
-            $protocol = eval { LWP::Protocol::create($scheme, $self) };
-            if ($@) {
-                $@ =~ s/ at .* line \d+.*//s;  # remove file/line number
-                $response =  _new_response($request, &HTTP::Status::RC_NOT_IMPLEMENTED, $@);
+            try {
+                $protocol = LWP::Protocol::create($scheme, $self);
+            }
+            catch {
+                my $error = $_;
+                $error =~ s/ at .* line \d+.*//s;  # remove file/line number
+                $response =  _new_response($request, &HTTP::Status::RC_NOT_IMPLEMENTED, $error);
                 if ($scheme eq "https") {
                     $response->message($response->message . " (LWP::Protocol::https not installed)");
                     $response->content_type("text/plain");
@@ -181,28 +186,28 @@ LWP will support https URLs if the LWP::Protocol::https module
 is installed.
 EOT
                 }
-            }
+            };
         }
 
         if (!$response && $self->{use_eval}) {
             # we eval, and turn dies into responses below
-            eval {
-                $response = $protocol->request($request, $proxy, $arg, $size, $self->{timeout}) ||
-		    die "No response returned by $protocol";
-            };
-            if ($@) {
-                if (UNIVERSAL::isa($@, "HTTP::Response")) {
-                    $response = $@;
+            try {
+                $response = $protocol->request($request, $proxy, $arg, $size, $self->{timeout}) || die "No response returned by $protocol";
+            }
+            catch {
+                my $error = $_;
+                if (blessed($error) && $error->isa("HTTP::Response")) {
+                    $response = $error;
                     $response->request($request);
                 }
                 else {
-                    my $full = $@;
-                    (my $status = $@) =~ s/\n.*//s;
+                    my $full = $error;
+                    (my $status = $error) =~ s/\n.*//s;
                     $status =~ s/ at .* line \d+.*//s;  # remove file/line number
                     my $code = ($status =~ s/^(\d\d\d)\s+//) ? $1 : &HTTP::Status::RC_INTERNAL_SERVER_ERROR;
                     $response = _new_response($request, $code, $status, $full);
                 }
-            }
+            };
         }
         elsif (!$response) {
             $response = $protocol->request($request, $proxy,
@@ -262,13 +267,14 @@ sub simple_request
         Carp::croak("No request object passed in");
     }
 
-    eval {
-	$request = $self->prepare_request($request);
-    };
-    if ($@) {
-	$@ =~ s/ at .* line \d+.*//s;  # remove file/line number
-	return _new_response($request, &HTTP::Status::RC_BAD_REQUEST, $@);
+    try {
+        $request = $self->prepare_request($request);
     }
+    catch {
+        my $error = $_;
+        $error =~ s/ at .* line \d+.*//s;  # remove file/line number
+        return _new_response($request, &HTTP::Status::RC_BAD_REQUEST, $error);
+    };
     return $self->send_request($request, $arg, $size);
 }
 
@@ -373,17 +379,22 @@ sub request
 	    no strict 'refs';
 	    unless (%{"$class\::"}) {
 		# try to load it
-		eval "require $class";
-		if ($@) {
-		    if ($@ =~ /^Can\'t locate/) {
+        try {
+            (my $req = $class) =~ s{::}{/}g;
+            $req .= '.pm' unless $req =~ /\.pm$/;
+            require $req;
+        }
+        catch {
+            my $error = $_;
+		    if ($error =~ /^Can\'t locate/) {
 			$response->header("Client-Warning" =>
 					  "Unsupported authentication scheme '$scheme'");
 		    }
 		    else {
-			$response->header("Client-Warning" => $@);
+			$response->header("Client-Warning" => $error);
 		    }
 		    next CHALLENGE;
-		}
+		};
 	    }
 	    unless ($class->can("authenticate")) {
 		$response->header("Client-Warning" =>
